@@ -33,7 +33,8 @@ void F77_SUB(hetmixlin)(double * Y0,
 			double * convL,
 			double * convG,
 			int * maxiter0,
-			int * fix0);
+			int * fix0,
+			int * pbH0);
 
 void F77_SUB(hetmixcont)(double * Y0,
 			 double * X0,
@@ -263,28 +264,30 @@ void F77_SUB(predictcont)(double * X0,
 
 
 void F77_SUB(predictmult)(double * X0,
-			   int * idprob,
-			   int * idea,
-			   int * idg,
-			   int * idcor,
-			   int * idcontr,
-			   int * ng,
-			   int * ncor,
-			   int * nalea,
-			   int * nv,
-			   int * ny,
-			   int * maxmes,
-			   int * idiag,
-			   int * nwg,
-			   int * npm,
-			   double * b1,
-			   double * epsY,
-			   int * idlink,
-			   int * nbzitr,
-			   double * zitr0,
-			   int * nsim,
-			   int * methInteg,
-			   double * Ymarg);
+			  int * idprob,
+			  int * idea,
+			  int * idg,
+			  int * idcor,
+			  int * idcontr,
+			  int * ng,
+			  int * ncor,
+			  int * nalea,
+			  int * nv,
+			  int * ny,
+			  int * maxmes,
+			  int * idiag,
+			  int * nwg,
+			  int * npm,
+			  double * b1,
+			  double * epsY,
+			  int * idlink,
+			  int * nbzitr,
+			  double * zitr0,
+			  int * modalite,
+			  int * nbmod,
+			  int * nsim,
+			  int * methInteg,
+			  double * Ymarg);
 
 void F77_SUB(predictcondmult)(double * X0,
 			      int * condRE_Y,
@@ -299,6 +302,8 @@ void F77_SUB(predictcondmult)(double * X0,
 			      int * idlink,
 			      int * nbzitr,
 			      double * zitr0,
+			      int * mod,
+			      int * nbmod,
 			      int * nsim,
 			      double * Ymarg);
 
@@ -468,3 +473,78 @@ void F77_SUB(mpjhet)(int * K0,
 		     int * contrainte);
 		     
 
+
+void F77_SUB(hetmixmult)(double * Y0, 
+			 double * X0, 
+			 int * Prior0, 
+			 int * idprob0,
+			 int * idea0,
+			 int * idg0,
+			 int * idcor0,
+			 int * idcontr0,
+			 int * ny0,
+			 int * ns0,
+			 int * ng0,
+			 int * nv0,
+			 int * nobs0,
+			 int * nea0,
+			 int * nmes0,
+			 int * idiag0,
+			 int * nwg0,
+			 int * ncor0,
+			 int * nalea0,
+			 int * npmtot0,
+			 double * btot,
+			 double * Vopt,
+			 double * vrais,
+			 int * ni,
+			 int * istop,
+			 double * gconv,
+			 double * ppi0,
+			 double * resid_m,
+			 double * resid_ss,
+			 double * pred_m_g,
+			 double * pred_ss_g,
+			 double * pred_RE,
+			 double * pred_RE_Y,
+			 double * convB,
+			 double * convL,
+			 double * convG,
+			 int * maxiter0,
+			 double * epsY0,
+			 int * idlink0,
+			 int * nbzitr0,
+			 double * zitr0,
+			 double * uniqueY0,
+			 int * indiceY0,
+			 int * nvalsplord0,
+			 double * marker,
+			 double * transfY,
+			 int * nsim0,
+			 double * Yobs,
+			 int * Ydiscret,
+			 double * vraisdiscret,
+			 double * UACV,
+			 double * rlindiv,
+			 int * pbH0,
+			 int * fix0,
+			 int * methInteg0,
+			 int * nMC0,
+			 int * dimMC0,
+			 double * seqMC0);
+
+void F77_SUB(iteminfo)(double * X0,
+		       int * condRE_Y,
+		       int * nalea,
+		       int * ny,
+		       int * maxmes,
+		       int * npm,
+		       double * b1,
+		       int * debut,
+                       int * nbzitr,
+		       int * idlink,
+		       int * mod,
+		       int * nbmod,
+		       int * nsim,
+		       int * ninfo,
+		       double * info);
